{% block content %}
    <article>
        <div class="container">
            <div class="row">
                <div class="col-lg-8 col-md-10 mx-auto">
                    {{ post.body | safe }}
                </div>
            </div>
        </div>
    </article>
{% endblock content %}
